<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'corvex_setup_theme' );
add_action( 'after_setup_theme', 'corvex_load_default_hooks' );


function corvex_setup_theme() {

	load_theme_textdomain( 'corvex', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support('woocommerce');
	add_theme_support('wc-product-gallery-lightbox');
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );


	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'corvex_370x310', 370, 310, true ); //'corvex_370x310 Our Services'
	add_image_size( 'corvex_70x70', 70, 70, true ); //'corvex_70x70 Our Testimonials'
	add_image_size( 'corvex_370x290', 370, 290, true ); //'corvex_370x290 Latest News'
	add_image_size( 'corvex_440x305', 440, 305, true ); //'corvex_440x305 Our Team'
	add_image_size( 'corvex_310x305', 310, 305, true ); //'corvex_310x305 Our Team V2'
	add_image_size( 'corvex_1170x440', 1170, 440, true ); //'corvex_1170x440 Our Blog'
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'corvex' ),
		'onepage_menu' => esc_html__( 'OnePage Menu', 'corvex' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'corvex_admin_init', 2000000 );
}

/**
 * [corvex_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function corvex_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [corvex_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function corvex_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'corvex' . '_options-mods' );

	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'corvex' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'corvex' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'corvex'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'corvex'),
		'before_widget'=>'<div class="col-xl-4 col-lg-6 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget single-footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="title"><h3>',
		'after_title' => '</h3></div>'
	));
	if ( class_exists( '\Elementor\Plugin' )){
	register_sidebar(array(
		'name' => esc_html__('RTL Footer Widget', 'corvex'),
		'id' => 'footer-sidebar-2',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'corvex'),
		'before_widget'=>'<div class="col-xl-3 col-lg-6 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget single-footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="title"><h3>',
		'after_title' => '</h3></div>'
	));
	register_sidebar(array(
		'name' => esc_html__('Services Widget', 'corvex'),
		'id' => 'service-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Services Area.', 'corvex'),
		'before_widget'=>'<div id="%1$s" class="service-widget single-sidebar %2$s">',
		'after_widget'=>'</div>',
		'before_title' => '<div class="title"><h3>',
		'after_title' => '</h3></div>'
	));
	}
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'corvex' ),
	  'id' => 'blog-sidebar',
'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'corvex' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="title"><h3>',
		'after_title'   => '</h3></div>',
	));
	if ( ! is_object( corvex_WSH() ) ) {
		return;
	}

	$sidebars = corvex_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( corvex_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget single-sidebar">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="title"><h3>',
			'after_title'   => '</h3></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'corvex_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function corvex_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'corvex' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'corvex' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'corvex' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'corvex' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'corvex' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'corvex' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'corvex' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'corvex' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'corvex' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'corvex_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function corvex_enqueue_scripts() {

	
    //styles
	wp_enqueue_style( 'aos', get_template_directory_uri() . '/assets/css/aos.css' );
	wp_enqueue_style( 'bootstrap-min', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'imp', get_template_directory_uri() . '/assets/css/imp.css' );
	wp_enqueue_style( 'custom-animate', get_template_directory_uri() . '/assets/css/custom-animate.css' );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css' );
	wp_enqueue_style( 'owl', get_template_directory_uri() . '/assets/css/owl.css' );
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css' );
	wp_enqueue_style( 'scrollbar', get_template_directory_uri() . '/assets/css/scrollbar.css' );
	wp_enqueue_style( 'hiddenbar', get_template_directory_uri() . '/assets/css/hiddenbar.css' );
	wp_enqueue_style( 'icomoon', get_template_directory_uri() . '/assets/css/icomoon.css' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	wp_enqueue_style( 'bootstrap-select', get_template_directory_uri() . '/assets/css/bootstrap-select.min.css' );
	wp_enqueue_style( 'date-picker', get_template_directory_uri() . '/assets/css/date-picker.css' );
	wp_enqueue_style( 'bxslider', get_template_directory_uri() . '/assets/css/jquery.bxslider.css' );
	wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css' );
	wp_enqueue_style( 'mCustomScrollbar', get_template_directory_uri() . '/assets/css/jquery.mCustomScrollbar.min.css' );
	wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/assets/css/jquery-ui.css' );
	wp_enqueue_style( 'polyglot-language-switcher', get_template_directory_uri() . '/assets/css/polyglot-language-switcher.css' );
	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/css/slick.css' );
	wp_enqueue_style( 'timePicker', get_template_directory_uri() . '/assets/css/timePicker.css' );
	wp_enqueue_style( 'bootstrap-touchspin', get_template_directory_uri() . '/assets/css/jquery.bootstrap-touchspin.css' );
	wp_enqueue_style( 'corvex-style-2', get_template_directory_uri() . '/assets/css/style-2.css' );	
	wp_enqueue_style( 'corvex-about-section', get_template_directory_uri() . '/assets/css/module-css/about-section.css' );
	wp_enqueue_style( 'corvex-banner-section', get_template_directory_uri() . '/assets/css/module-css/banner-section.css' );
	wp_enqueue_style( 'corvex-blog-section', get_template_directory_uri() . '/assets/css/module-css/blog-section.css' );
	wp_enqueue_style( 'corvex-breadcrumb-section', get_template_directory_uri() . '/assets/css/module-css/breadcrumb-section.css' );
	wp_enqueue_style( 'corvex-choose-section', get_template_directory_uri() . '/assets/css/module-css/choose-section.css' );
	wp_enqueue_style( 'corvex-contact-page', get_template_directory_uri() . '/assets/css/module-css/contact-page.css' );
	wp_enqueue_style( 'corvex-fact-counter-section', get_template_directory_uri() . '/assets/css/module-css/fact-counter-section.css' );
	wp_enqueue_style( 'corvex-faq-section', get_template_directory_uri() . '/assets/css/module-css/faq-section.css' );
	wp_enqueue_style( 'corvex-footer-section', get_template_directory_uri() . '/assets/css/module-css/footer-section.css' );
	wp_enqueue_style( 'corvex-gallery-section', get_template_directory_uri() . '/assets/css/module-css/gallery-section.css' );
	wp_enqueue_style( 'corvex-header-section', get_template_directory_uri() . '/assets/css/module-css/header-section.css' );
	wp_enqueue_style( 'corvex-service-section', get_template_directory_uri() . '/assets/css/module-css/service-section.css' );
	wp_enqueue_style( 'corvex-team-section', get_template_directory_uri() . '/assets/css/module-css/team-section.css' );
	wp_enqueue_style( 'corvex-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	wp_enqueue_style( 'corvex-testimonial-section', get_template_directory_uri() . '/assets/css/module-css/testimonial-section.css' );
	wp_enqueue_style( 'corvex-video-gallery-section', get_template_directory_uri() . '/assets/css/module-css/video-gallery-section.css' );
	wp_enqueue_style( 'corvex-thm-form-section', get_template_directory_uri() . '/assets/css/module-css/thm-form-section.css' );
	wp_enqueue_style( 'corvex-color', get_template_directory_uri() . '/assets/css/color.css' );
	wp_enqueue_style( 'corvex-sidebar', get_template_directory_uri() . '/assets/css/theme/sidebar.css' );
	wp_enqueue_style( 'corvex-error', get_template_directory_uri() . '/assets/css/theme/error.css' );
	wp_enqueue_style( 'corvex-fixing', get_template_directory_uri() . '/assets/css/theme/fixing.css' );
	wp_enqueue_style( 'corvex-gutenberg', get_template_directory_uri() . '/assets/css/theme/gutenberg.css' );
	wp_enqueue_style( 'corvex-tut', get_template_directory_uri() . '/assets/css/theme/tut.css' );
	wp_enqueue_style( 'corvex-main', get_stylesheet_uri() );
	wp_enqueue_style( 'corvex-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'corvex-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	wp_enqueue_style( 'corvex-rtl', get_template_directory_uri() . '/assets/css/rtl.css' );
	//temp
	 wp_enqueue_style( 'color-panel', get_template_directory_uri() . '/assets/css/color-panel.css' );
	
    //scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'aos', get_template_directory_uri().'/assets/js/aos.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bundle', get_template_directory_uri().'/assets/js/bootstrap.bundle.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotope.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bxslider', get_template_directory_uri().'/assets/js/jquery.bxslider.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'countdown', get_template_directory_uri().'/assets/js/jquery.countdown.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'countTo', get_template_directory_uri().'/assets/js/jquery.countTo.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'easing', get_template_directory_uri().'/assets/js/jquery.easing.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'enllax', get_template_directory_uri().'/assets/js/jquery.enllax.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'fancybox', get_template_directory_uri().'/assets/js/jquery.fancybox.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri().'/assets/js/jquery.magnific-popup.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'paroller', get_template_directory_uri().'/assets/js/jquery.paroller.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'language-switcher', get_template_directory_uri().'/assets/js/jquery.polyglot.language.switcher.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'style-switcher', get_template_directory_uri().'/assets/js/jQuery.style.switcher.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-ui', get_template_directory_uri().'/assets/js/jquery-ui.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'knob', get_template_directory_uri().'/assets/js/knob.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'owl', get_template_directory_uri().'/assets/js/owl.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'pagenav', get_template_directory_uri().'/assets/js/pagenav.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'parallax', get_template_directory_uri().'/assets/js/parallax.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'scrollbar', get_template_directory_uri().'/assets/js/scrollbar.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'slick', get_template_directory_uri().'/assets/js/slick.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'timePicker', get_template_directory_uri().'/assets/js/timePicker.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'tweenMax', get_template_directory_uri().'/assets/js/TweenMax.min.js', array( 'jquery' ), '2.1.2', true );
	
	wp_enqueue_script( 'corvex-main-script', get_template_directory_uri().'/assets/js/custom.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
	
	//temp
	wp_enqueue_script( 'themepanel', get_template_directory_uri().'/assets/js/themepanel.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery.cookie', get_template_directory_uri().'/assets/js/jquery.cookie.js', array( 'jquery' ), '2.1.2', true );
}
add_action( 'wp_enqueue_scripts', 'corvex_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function corvex_fonts_url() {
	
	$fonts_url = '';

		$font_families['Rubik']      = 'Rubik:300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,500;1,600;1,700;1,800;1,900';
		
		$font_families['Spartan']      = 'Spartan:300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,500;1,600;1,700;1,800;1,900';

		$font_families = apply_filters( 'REXAR/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function corvex_theme_styles() {
    wp_enqueue_style( 'corvex-theme-fonts', corvex_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'corvex_theme_styles' );
add_action( 'admin_enqueue_scripts', 'corvex_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) corvex_set function

/**
 * [corvex_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'corvex_set' ) ) {
	function corvex_set( $var, $key, $def = '' ) {
		//if( ! $var ) return false;

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) corvex_add_editor_styles function

function corvex_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'corvex_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = corvex_WSH()->option(); 
if( corvex_set($options, 'boxed_wrapper') ){

	add_filter( 'body_class', function( $classes ) {
		$classes[] = 'boxed_wrapper';
		return $classes;
	} );
}

function corvex_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
/**
 * product per page
 */
add_filter( 'loop_shop_per_page', 'corvex_loop_shop_per_page', 20 );

function corvex_loop_shop_per_page( $cols ) {
		$options     = corvex_WSH()->option();		
		$shop_product = esc_attr( $options->get( 'shop_product') );	
		
  // $cols contains the current number of products per page based on the value stored on Options –> Reading
  // Return the number of products you wanna show per page.
  $cols =  $shop_product;
  return $cols;
}


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328282&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        