<?php
/**
 * The header for our theme
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @package CORVEX
 * @since   1.0
 * @version 1.0
 */
$options = corvex_WSH()->option();
$allowed_html = wp_kses_allowed_html( 'post' );

//Logo Settings
$image_logo = $options->get( 'image_normal_logo' );
$logo_dimension = $options->get( 'normal_logo_dimension' );

$image_logo2 = $options->get( 'image_normal_logo2' );
$logo_dimension2 = $options->get( 'normal_logo_dimension2' );

$image_logo3 = $options->get( 'image_normal_logo3' );
$logo_dimension3 = $options->get( 'normal_logo_dimension3' );


$icon_href = $options->get( 'image_favicon' ); 
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<?php if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ): ?>
		<?php if( $icon_href ):?>
		
		<link rel="apple-touch-icon" sizes="180x180" href="<?php echo esc_url($icon_href['url']); ?>">
		<link rel="icon" type="image/png" href="<?php echo esc_url($icon_href['url']); ?>" sizes="32x32">
		<link rel="icon" type="image/png" href="<?php echo esc_url($icon_href['url']); ?>" sizes="16x16">
		
		<?php endif; ?>
	<?php endif; ?>
	<!-- responsive meta -->
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<!-- For IE -->
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <?php wp_head(); ?>
</head>
		

<body <?php body_class(); ?>> 

<?php
if ( ! function_exists( 'wp_body_open' ) ) {
		function wp_body_open() {
			do_action( 'wp_body_open' );
		}
}?>
	
<div class="boxed_wrapper <?php if($options->get( 'theme_rtl' ) ): echo esc_attr_e( 'rtl', 'corvex' ); endif;?>">	
	
<?php do_action( 'corvex_main_header' ); ?>	
		
 <?php if(!$options->get( 'theme_preloader' ) ):?>		
	<!-- Preloader -->
	<div class="loader-wrap">
		<div class="preloader"><div class="preloader-close"><?php esc_html_e('Preloader Close ', 'corvex'); ?></div></div>
		<div class="layer layer-one"><span class="overlay"></span></div>
		<div class="layer layer-two"><span class="overlay"></span></div>        
		<div class="layer layer-three"><span class="overlay"></span></div>        
	</div>
 <?php endif; ?>
	
	
	
<!-- Hidden Navigation Bar -->
<section class="hidden-bar right-align">
    <div class="hidden-bar-closer">
        <button><span class="flaticon-multiply"></span></button>
    </div>
    <div class="hidden-bar-wrapper">
        <div class="logo">
            <?php echo corvex_logo( $logo_type, $image_logo2, $logo_dimension, $logo_text, $logo_typography ); ?>
        </div>
        <div class="hiddenbar-about-us">
            <h3><?php echo wp_kses( $options->get( 'about_title'), $allowed_html ); ?></h3>
            <div class="text">
                <p><?php echo wp_kses( $options->get( 'about_text'), $allowed_html ); ?></p>
            </div>    
        </div>
        <div class="contact-info-box">
            <h3><?php echo wp_kses( $options->get( 'contact_title'), $allowed_html ); ?></h3>
            <ul>
                <li>
                    <h5><?php echo wp_kses( $options->get( 'address_title'), $allowed_html ); ?></h5>
                    <p><?php echo wp_kses( $options->get( 'address_text'), $allowed_html ); ?></p>
                </li>
                <li>
                    <h5><?php echo wp_kses( $options->get( 'phone_title'), $allowed_html ); ?></h5>
                    <p><a href="#"><?php echo wp_kses( $options->get( 'phone_number'), $allowed_html ); ?></a></p>
                </li>
                <li>
                    <h5><?php echo wp_kses( $options->get( 'email_title'), $allowed_html ); ?></h5>
                    <p><a href="#"><?php echo wp_kses( $options->get( 'email_address'), $allowed_html ); ?></a></p>
                </li>
            </ul>
        </div>       
        <div class="newsletter-form-box">
            <h3><?php echo wp_kses( $options->get( 'subscribe_title'), $allowed_html ); ?></h3>
            <form action="<?php echo esc_url( home_url( '/' ) ); ?>">
                <div class="row">
                    <div class="col-xl-12">
                        <input type="email" name="email" placeholder="<?php echo esc_attr__( 'Search here', 'corvex' ); ?>"> 
                        <button type="submit"><i class="fa fa-paper-plane" aria-hidden="true"></i></button>    
                    </div>
                </div>
            </form>
        </div>
        <div class="copy-right-text">
            <p><?php echo wp_kses( $options->get( 'copy_right_text'), $allowed_html ); ?></p>
        </div> 
    </div>
</section>
<!-- End Hidden Bar -->     
